
ScrewJack
=========

ScrewJack is a tiny command line tool for manipulating modules.

Installation
------------

Install directly by pip:

```sh
pip install -U screwjack
```

Or, you can use the latest version:

```sh
git clone http://github.com/DataCanvasIO/screwjack.git screwjack.git
cd screwjack.git
pip install -r requirements.txt
./bin/screwjack --help
```

Usage
-----

[Online document](http://screwjack.readthedocs.org) is also avaliable.

About
-----

ScrewJack is licensed under BSD (3-Clause) License, see LICENSE file for detail. Comments and contribution are welcome.
